aboutsummaryrefslogtreecommitdiff
path: root/include/lldb/lldb-types.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/lldb/lldb-types.h')
-rw-r--r--include/lldb/lldb-types.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/include/lldb/lldb-types.h b/include/lldb/lldb-types.h
index fee920f5b198..fe902073698d 100644
--- a/include/lldb/lldb-types.h
+++ b/include/lldb/lldb-types.h
@@ -50,9 +50,12 @@ namespace lldb
typedef void* condition_t;
typedef void* rwlock_t;
typedef void* process_t; // Process type is HANDLE
- typedef uintptr_t thread_t; // Host thread type
+ typedef void* thread_t; // Host thread type
+ typedef void* file_t; // Host file type
+ typedef void* pipe_t; // Host pipe type
+ typedef unsigned int __w64 socket_t; // Host socket type
typedef uint32_t thread_key_t;
- typedef void * thread_arg_t; // Host thread argument type
+ typedef void* thread_arg_t; // Host thread argument type
typedef unsigned thread_result_t; // Host thread result type
typedef thread_result_t (*thread_func_t)(void *); // Host thread function type
}
@@ -71,6 +74,9 @@ namespace lldb
typedef pthread_rwlock_t rwlock_t;
typedef uint64_t process_t; // Process type is just a pid.
typedef pthread_t thread_t; // Host thread type
+ typedef int file_t; // Host file type
+ typedef int pipe_t; // Host pipe type
+ typedef int socket_t; // Host socket type
typedef pthread_key_t thread_key_t;
typedef void * thread_arg_t; // Host thread argument type
typedef void * thread_result_t; // Host thread result type
@@ -89,6 +95,7 @@ namespace lldb
typedef bool (*ExpressionCancelCallback) (ExpressionEvaluationPhase phase, void *baton);
}
+#define LLDB_INVALID_PROCESS ((lldb::process_t)-1)
#define LLDB_INVALID_HOST_THREAD ((lldb::thread_t)NULL)
#define IS_VALID_LLDB_HOST_THREAD(t) ((t) != LLDB_INVALID_HOST_THREAD)